===========================================
HDFS Contents Manager for Jupyter Notebooks
===========================================

A contents manager for Jupyter that uses the Hadoop File System (HDFS) to store Notebooks and files
